@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# const.py - A set of structures and constants used to implement the Ethernet/IP protocol
-#
-# Copyright (c) 2019 Ian Ottoway <ian@ottoway.dev>
+# Copyright (c) 2020 Ian Ottoway <ian@ottoway.dev>
 # Copyright (c) 2014 Agostino Ruscito <ruscito@gmail.com>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -31,9 +29,10 @@ logger.addHandler(logging.NullHandler())
 
 
 from ._version import __version__, __version_info__
-from .cip_base import CIPDriver
-from .clx import LogixDriver
 from .const import CommonService, ClassCode, TagService, DataType, ConnectionManagerInstance, ConnectionManagerService
 from .bytes_ import Pack, Unpack
 from .tag import Tag
 from .exceptions import PycommError, CommError, DataError, RequestError
+from .cip_base import CIPDriver
+from .clx import LogixDriver
+from .slc import SLCDriver
